@@ -1,16 +1,16 @@
 package Tapper::Benchmark;
-# git description: v0.004-7-g7631791
+# git description: v0.005-4-ga32373c
 
 BEGIN {
   $Tapper::Benchmark::AUTHORITY = 'cpan:TAPPER';
 }
 # ABSTRACT: Autonomous SQL backend to store benchmarks
-$Tapper::Benchmark::VERSION = '0.005';
+$Tapper::Benchmark::VERSION = '0.006';
 use strict;
 use warnings;
 
 my $hr_default_config = {
-    select_cache        => 1,
+    select_cache        => 0,
     default_aggregation => 'min',
     tables              => {
         unit_table                       => 'bench_units',
@@ -845,10 +845,6 @@ Ignore forgivable errors while writing.
 
 =head3 add_multi_benchmark
 
-=over 4
-
-=item
-
 Add one or more data points for multiple benchmarks to the database.
 
     my $b_success = $or_bench->add_multi_benchmark([
@@ -897,14 +893,8 @@ Ignore forgivable errors while writing.
 
 =back
 
-=back
-
 =head3 search
 
-=over 4
-
-=item
-
 Search for benchmark data points in the database. Function returns a DBI
 Statement Handle.
 
@@ -1057,14 +1047,8 @@ An integer value which determine the number of omitted benchmark data points.
 
 =back
 
-=back
-
 =head3 search_array
 
-=over 4
-
-=item
-
 Returning all benchmark data points as Array of Hashes.
 
     my $or_benchmark_points = $or_bench->search_array({
@@ -1084,14 +1068,8 @@ Returning all benchmark data points as Array of Hashes.
         ],
     });
 
-=back
-
 =head3 search_hash
 
-=over 4
-
-=item
-
 Returning all benchmark data points as Hash of Hashes. As compared to search
 C<search_array> this function needs the parameter C<keys>. C<keys> is an Array
 of Strings which determine the columns used as the keys for the nested hashes.
@@ -1119,14 +1097,22 @@ Every "key" create a new nested hash.
         ],
     });
 
-=back
+=head3 select_benchmark_point_essentials
+
+Get a single data points from the database including all essential
+fields (NAME, VALUE, UNIT) and additional fields.
+
+ my $point = $or_bench->get_single_benchmark_point($value_id);
+
+=head3 list_benchmark_names
+
+Get a list of all benchmark NAMEs, optionally matching a given pattern
+(SQL LIKE syntax, i.e., using C<%> as placeholder.
+
+ $benchmarkanythingdata = $or_bench->list_benchmark_names($pattern);
 
 =head3 subsume
 
-=over 4
-
-=item
-
 This is a maintenance function for reducing the number of data points in the
 database. Calling this function reduces the rows in the benchmark values table
 by building an average value for all benchmark data points grouped by specfic
@@ -1176,18 +1162,12 @@ isn't desired a false value must be passed.
 
 =back
 
-=back
-
 =head1 NAME
 
 Tapper::Benchmark - Save and search benchmark points by database
 
 =head1 Configuration
 
-=over 4
-
-=item
-
 The following elements are required in configuration:
 
 =over 4
@@ -1220,8 +1200,6 @@ In case of a true value the module cache some select results
 
 =back
 
-=back
-
 =head1 AUTHOR
 
 Roberto Schaefer <schaefr@amazon.com>
